# USER SETTINGS FOR BI CLIP USAGE UTILITY
#
# KEY POINTS: 
#   1. This script is intended to be used by companion script 'BI_clip_usage.ps1'
#   2. This script must be located in the same folder as script 'BI_clip_usage.ps1'
#   3. This script is suitable for 'BI_clip_usage.ps1' versions V7.1+
#
# Created by jaydeel at ipcamtalk.com

# ================================================
# USER SETTINGS...

# REQUIRED SETTINGS

	# APPLICATION

		# ENTER DESTINATION PATH THE SCRIPT'S OUTPUT
		# ... (string) like "D:\BI_clip_usage"
		$app_path = 'YOUR_SCRIPT_WORKING_FOLDER_PATH'
		#$app_path = "D:\BI_clip_usage"

# OPTIONAL SETTINGS

	# OPT OUT OF CHECKS AND MESSAGING INTENDED TO HELP NEW USERS
	# ... Expecting $true or $false (default is $false)
	$experienced_user_flg = $false
	#$experienced_user_flg = $true

	# OPT OUT OF ANALYSIS OF THESE BLUE IRIS MANAGED FOLDERS (IF THEY EXIST)
	# ... KEY POINT: $show_folder1 to $show_folder3 must be New, Storage, Alerts in that order; 
	#                likewise,$show_folder4 to $show_folder16 must be Aux1-13
	# ... Expecting $true or $false (default is $true for folders 1-3, $false for 4-16)
	# ... The order the folders are displayed cannot be changed
	$show_folder1 = $true     # 'New' folder,     like 'D:\BlueIris\New'
	$show_folder2 = $true     # 'Storage' folder, like 'D:\BlueIris\Storage'
	$show_folder3 = $true     # 'Alerts' folder,  like 'D:\BlueIris\Alerts
	$show_folder4 = $false    # 'Aux 1' folder,   like 'D:\BlueIris\Aux1'
	$show_folder5 = $false    # 'Aux 2' folder,   like 'D:\BlueIris\Aux2'
	$show_folder6 = $false    # 'Aux 3' folder,   like 'D:\BlueIris\Aux3'
	$show_folder7 = $false    # 'Aux 4' folder,   like 'D:\BlueIris\Aux4'
	$show_folder8 = $false    # 'Aux 5' folder,   like 'D:\BlueIris\Aux5'
	$show_folder9 = $false    # 'Aux 6' folder,   like 'D:\BlueIris\Aux6'
	$show_folder10 = $false   # 'Aux 7' folder,   like 'D:\BlueIris\Aux7'
	$show_folder11 = $false   # 'Aux 8' folder,   like 'D:\BlueIris\Aux8'
	$show_folder12 = $false   # 'Aux 9' folder,   like 'D:\BlueIris\Aux9'
	$show_folder13 = $false   # 'Aux 10' folder,  like 'D:\BlueIris\Aux10'
	$show_folder14 = $false   # 'Aux 11' folder,  like 'D:\BlueIris\Aux11'
	$show_folder15 = $false   # 'Aux 12' folder,  like 'D:\BlueIris\Aux13'
	$show_folder16 = $false   # 'Aux 13' folder,  like 'D:\BlueIris\Aux13'

	# OVERRIDE BLUE IRIS FOLDER PATHS
	# ... Expecting string; default is "" (blank)
	# ... Useful for testing. For example, alternate Blue Iris filename formats.
	# ... NOTE: Variable names must be unique and in the range $override_folder1-$override_folder16.
	#$override_folder1 = "D:\BlueIris2\New"
	#$override_folder4 = "J:"

	# OVERRIDE AUTO-DETERMINATION OF THE DEFAULT CLIP NAME 'FILE FORMAT'
	# ... Comment out this user setting to allow the script to auto-determine the 'File Format' state;
	#     NOTE: auto-determination requires Blue Iris webserver credentials (see section below)
	# ... By default, if the following conditions are true FOR ANY CAMERA, the script assumes that 
	#     a QUALIFIED non-default filename format is being used by Blue Iris,
	#     1. The camera is ENABLED
	#     2. Either 'Video' or 'JPGs' recording is enabled (Camera settings > Record tab)
	#     3. The 'Use default' folder setting is NOT CHECKED
	#     4. The custom filename format INCLUDES SUB-FOLDERS ... e.g. '&CAM\%d-%m-%y\&CAM.%Y%m%d_%H%M%S'
	#     5. The final element of the custom filename format starts or ends with '&CAM'
	#     6. the segment at the opposite end of the filename must begin with a BI datetime macro ('%' character)
	#     NOTE: per the Blue Iris Help PDF, 
	#           A. The actual filename portion of the path should always either begin or end with 
	#              the camera name, either &CAM.xxxx or xxxx.&CAM
	#           B. the short name must not begin with a number, while the segment at the opposite end 
	#              of the filename must begin with a number (typically part of the date or time)
	#$default_filename_format_flg = $true
	#$default_filename_format_flg = $false

	# OPT OUT OF TIME STAMPING THE 'OUTPUT.CSV' FILES
	# ... Expecting $true or $false (default is $true)
	# ... These files are located in folder '$app_path'
	$timestamp_output_csv_files_flg = $true
	#$timestamp_output_csv_files_flg = $false

	# ENTER MAX LIFETIME FOR ARCHIVED 'OUTPUT.CSV' FILES
	# ... Expecting integer (default is 365)
	# ... 'output.csv' files archived by this script are saved to folder '$app_path'
	# ... To prevent this folder from growing excessively large, this setting deletes CSV files after a given age
	# ... (aka a 'pruning operation' that searches for output*_20*.csv older than a retention time)
	# ... TIP: Use 0 to disable monitoring of the archive folder
	# ... TIP: Use ANY negative number to prune ALL the CSV files
	$archive_lifetime_days = 365
	#$archive_lifetime_days = 0
	#$archive_lifetime_days = -1  # CAREFUL!

	# BLUE IRIS WEBSERVER
	
		# REQUIRED IF SETTING $default_filename_format_flg is commented out

		# ENTER YOUR WEBSERVER'S ADDRESS & PORT
		# ... [string] like '192.168.1.3:81'
		$bi_webserver = "YOUR_BI_SERVER_ADDRESS:PORT"

		# ENTER YOUR WEBSERVER'S USERNAME & PASSWORD CREDENTIALS
		# ... CREDENTIALS ARE REQUIRED TO ACCESS THE BLUE IRIS WEBSERVER VIA THE JSON INTERFACE
		# ... NOTE: ACCOUNT MUST BE ADMIN if posting to the Blue Iris logfile
		# ... NOTE: to use credentials, be sure to uncheck 'Use secure session keys and login page' 
		#     in Blue Iris settings: click Settings > Web server > Advanced
		# ... [string] 
		$bi_user_name = "YOUR_BI_USER_NAME"
		$bi_user_pw = "YOUR_BI_USER_PASSORD"

# END USER SETTINGS
# ================================================
